@@ -168,6 +168,254 @@ class Test(unittest.TestCase):
 		self.assertEqual(sql, dest_sql)
 		self.assertEqual(many_params, dest_params)
 
+	def test_1_named_oracle_1_to_pyformat_1_no_quotes(self):
+		"""
+		Test converting from::
+
+			... WHERE name = :name
+
+		to::
+
+			... WHERE name = %(NAME)s
+		"""
+		# Create instance.
+		query = sqlparams.SQLParams('named_oracle', 'pyformat')
+
+		# Source SQL and params.
+		src_sql = """
+			SELECT *
+			FROM users
+			WHERE id = :ID OR name = :Name AND race = :race;
+		"""
+		src_params = {'id': 4, 'NAME': "Fili", 'Race': "dwarf"}
+
+		# Desired SQL and params.
+		dest_sql = """
+			SELECT *
+			FROM users
+			WHERE id = %(ID)s OR name = %(NAME)s AND race = %(RACE)s;
+		"""
+		dest_params = {__key.upper(): __val for __key, __val in src_params.items()}
+
+		# Format SQL with params.
+		sql, params = query.format(src_sql, src_params)
+
+		# Make sure desired SQL and parameters are created.
+		self.assertEqual(sql, dest_sql)
+		self.assertEqual(params, dest_params)
+
+	def test_1_named_oracle_1_to_pyformat_2_quotes(self):
+		"""
+		Test converting from::
+
+			... WHERE name = :"name"
+
+		to::
+
+			... WHERE name = %(name)s
+		"""
+		# Create instance.
+		query = sqlparams.SQLParams('named_oracle', 'pyformat')
+
+		# Source SQL and params.
+		src_sql = """
+			SELECT *
+			FROM users
+			WHERE id = :"ID" OR name = :"Name" AND race = :"race";
+		"""
+		src_params = {'"ID"': 4, '"Name"': "Fili", '"race"': "dwarf"}
+
+		# Desired SQL and params.
+		dest_sql = """
+			SELECT *
+			FROM users
+			WHERE id = %(ID)s OR name = %(Name)s AND race = %(race)s;
+		"""
+		dest_params = {
+			__key.strip('"'): __val for __key, __val in src_params.items()
+		}
+
+		# Format SQL with params.
+		sql, params = query.format(src_sql, src_params)
+
+		# Make sure desired SQL and parameters are created.
+		self.assertEqual(sql, dest_sql)
+		self.assertEqual(params, dest_params)
+
+	def test_1_named_oracle_1_to_pyformat_3_mixed(self):
+		"""
+		Test converting from::
+
+			... WHERE name = :"name"
+
+		to::
+
+			... WHERE name = %(name)s
+		"""
+		# Create instance.
+		query = sqlparams.SQLParams('named_oracle', 'pyformat')
+
+		# Source SQL and params.
+		src_sql = """
+			SELECT *
+			FROM users
+			WHERE id = :"ID" OR name = :"Name" AND race = :race;
+		"""
+		src_params = {'id': 4, '"Name"': "Fili", '"RACE"': "Dwarf"}
+
+		# Desired SQL and params.
+		dest_sql = """
+			SELECT *
+			FROM users
+			WHERE id = %(ID)s OR name = %(Name)s AND race = %(RACE)s;
+		"""
+		dest_params = {
+			(__key.strip('"') if '"' in __key else __key.upper()): __val
+			for __key, __val in src_params.items()
+		}
+
+		# Format SQL with params.
+		sql, params = query.format(src_sql, src_params)
+
+		# Make sure desired SQL and parameters are created.
+		self.assertEqual(sql, dest_sql)
+		self.assertEqual(params, dest_params)
+
+	def test_1_named_oracle_2_to_pyformat_1_many_no_quotes(self):
+		"""
+		Test converting many from::
+
+			... WHERE name = :name
+
+		to::
+
+			... WHERE name = %(NAME)s
+		"""
+		# Create instance.
+		query = sqlparams.SQLParams('named_oracle', 'pyformat')
+
+		# Source SQL and params.
+		# - WARNING: Only the first row is scanned for the in-parameter names. All
+		#   subsequent rows must have the exact same in-parameter names.
+		src_sql = """
+			SELECT *
+			FROM users
+			WHERE id = :ID OR name = :Name AND race = :race;
+		"""
+		src_params = [
+			{'id': 6, 'NAME': "Nori", 'Race': "dwarf"},
+			{'id': 2, 'NAME': "Balin", 'Race': "dwarf"},
+			{'id': 10, 'NAME': "Bifur", 'Race': "dwarf"},
+		]
+
+		# Desired SQL and params.
+		dest_sql = """
+			SELECT *
+			FROM users
+			WHERE id = %(ID)s OR name = %(NAME)s AND race = %(RACE)s;
+		"""
+		dest_params = [
+			{__key.upper(): __val for __key, __val in __row.items()}
+			for __row in src_params
+		]
+
+		# Format SQL with params.
+		sql, many_params = query.formatmany(src_sql, src_params)
+
+		# Make sure desired SQL and parameters are created.
+		self.assertEqual(sql, dest_sql)
+		self.assertEqual(many_params, dest_params)
+
+	def test_1_named_oracle_2_to_pyformat_2_many_quotes(self):
+		"""
+		Test converting many from::
+
+			... WHERE name = :"name"
+
+		to::
+
+			... WHERE name = %(NAME)s
+		"""
+		# Create instance.
+		query = sqlparams.SQLParams('named_oracle', 'pyformat')
+
+		# Source SQL and params.
+		# - WARNING: Only the first row is scanned for the in-parameter names. All
+		#   subsequent rows must have the exact same in-parameter names.
+		src_sql = """
+			SELECT *
+			FROM users
+			WHERE id = :"ID" OR name = :"Name" AND race = :"race";
+		"""
+		src_params = [
+			{'"ID"': 6, '"Name"': "Nori", '"race"': "dwarf"},
+			{'"ID"': 2, '"Name"': "Balin", '"race"': "dwarf"},
+			{'"ID"': 10, '"Name"': "Bifur", '"race"': "dwarf"},
+		]
+
+		# Desired SQL and params.
+		dest_sql = """
+			SELECT *
+			FROM users
+			WHERE id = %(ID)s OR name = %(Name)s AND race = %(race)s;
+		"""
+		dest_params = [
+			{__key.strip('"'): __val for __key, __val in __row.items()}
+			for __row in src_params
+		]
+
+		# Format SQL with params.
+		sql, many_params = query.formatmany(src_sql, src_params)
+
+		# Make sure desired SQL and parameters are created.
+		self.assertEqual(sql, dest_sql)
+		self.assertEqual(many_params, dest_params)
+
+	def test_1_named_oracle_2_to_pyformat_3_many_mixed(self):
+		"""
+		Test converting many from::
+
+			... WHERE name = :"name"
+
+		to::
+
+			... WHERE name = %(NAME)s
+		"""
+		# Create instance.
+		query = sqlparams.SQLParams('named_oracle', 'pyformat')
+
+		# Source SQL and params.
+		# - WARNING: Only the first row is scanned for the in-parameter names. All
+		#   subsequent rows must have the exact same in-parameter names.
+		src_sql = """
+			SELECT *
+			FROM users
+			WHERE id = :"ID" OR name = :"Name" AND race = :race;
+		"""
+		src_params = [
+			{'id': 6, '"Name"': "Nori", '"RACE"': "dwarf"},
+			{'id': 2, '"Name"': "Balin", '"RACE"': "dwarf"},
+			{'id': 10, '"Name"': "Bifur", '"RACE"': "dwarf"},
+		]
+
+		# Desired SQL and params.
+		dest_sql = """
+			SELECT *
+			FROM users
+			WHERE id = %(ID)s OR name = %(Name)s AND race = %(RACE)s;
+		"""
+		dest_params = [{
+			(__key.strip('"') if '"' in __key else __key.upper()): __val
+			for __key, __val in __row.items()
+		} for __row in src_params]
+
+		# Format SQL with params.
+		sql, many_params = query.formatmany(src_sql, src_params)
+
+		# Make sure desired SQL and parameters are created.
+		self.assertEqual(sql, dest_sql)
+		self.assertEqual(many_params, dest_params)
+
 	def test_1_pyformat_to_named(self):
 		"""
 		Test converting from::
@@ -245,6 +493,78 @@ class Test(unittest.TestCase):
 		self.assertEqual(sql, dest_sql)
 		self.assertEqual(many_params, dest_params)
 
+	def test_1_pyformat_to_named_oracle_no_quote(self):
+		"""
+		Test converting from::
+
+			... WHERE name = %(name)s
+
+		to::
+
+			... WHERE name = :name
+		"""
+		# Create instance.
+		query = sqlparams.SQLParams('pyformat', 'named_oracle')
+
+		# Source SQL and params.
+		src_sql = """
+			SELECT *
+			FROM users
+			WHERE id = %(id)s OR name = %(name)s;
+		"""
+		src_params = {'id': 4, 'name': "Fili"}
+
+		# Desired SQL and params.
+		dest_sql = """
+			SELECT *
+			FROM users
+			WHERE id = :id OR name = :name;
+		"""
+		dest_params = copy.deepcopy(src_params)
+
+		# Format SQL with params.
+		sql, params = query.format(src_sql, src_params)
+
+		# Make sure desired SQL and parameters are created.
+		self.assertEqual(sql, dest_sql)
+		self.assertEqual(params, dest_params)
+
+	def test_1_pyformat_to_named_oracle_quote(self):
+		"""
+		Test converting from::
+
+			... WHERE name = %(name)s
+
+		to::
+
+			... WHERE name = :"name"
+		"""
+		# Create instance.
+		query = sqlparams.SQLParams('pyformat', 'named_oracle', allow_out_quotes=True)
+
+		# Source SQL and params.
+		src_sql = """
+			SELECT *
+			FROM users
+			WHERE id = %(id)s OR name = %(name)s;
+		"""
+		src_params = {'id': 4, 'name': "Fili"}
+
+		# Desired SQL and params.
+		dest_sql = """
+			SELECT *
+			FROM users
+			WHERE id = :"id" OR name = :"name";
+		"""
+		dest_params = {f'"{k}"': src_params[k] for k in src_params}
+
+		# Format SQL with params.
+		sql, params = query.format(src_sql, src_params)
+
+		# Make sure desired SQL and parameters are created.
+		self.assertEqual(sql, dest_sql)
+		self.assertEqual(params, dest_params)
+
 	def test_2_expand_tuples(self):
 		"""
 		Test expanding tuples.
@@ -266,7 +586,50 @@ class Test(unittest.TestCase):
 			FROM users
 			WHERE race = :race AND name IN (:names__0_sqlp,:names__1_sqlp);
 		"""
-		dest_params = {'race': src_params['race'], 'names__0_sqlp': src_params['names'][0], 'names__1_sqlp': src_params['names'][1]}
+		dest_params = {
+			'race': src_params['race'],
+			'names__0_sqlp': src_params['names'][0],
+			'names__1_sqlp': src_params['names'][1],
+		}
+
+		# Format SQL with params.
+		sql, params = query.format(src_sql, src_params)
+
+		# Make sure desired SQL and parameters are created.
+		self.assertEqual(sql, dest_sql)
+		self.assertEqual(params, dest_params)
+
+	def test_2_expand_tuples_oracle(self):
+		"""
+		Test expanding tuples.
+		"""
+		# Create instance.
+		query = sqlparams.SQLParams(
+			in_style='named',
+			out_style='named_oracle',
+			expand_tuples=True,
+			allow_out_quotes=True,
+		)
+
+		# Source SQL and params.
+		src_sql = """
+			SELECT *
+			FROM users
+			WHERE race = :race AND name IN :names;
+		"""
+		src_params = {'names': ("Dwalin", "Balin"), 'race': "Dwarf"}
+
+		# Desired SQL and params.
+		dest_sql = """
+			SELECT *
+			FROM users
+			WHERE race = :"race" AND name IN (:"names__0_sqlp",:"names__1_sqlp");
+		"""
+		dest_params = {
+			'"race"': src_params['race'],
+			'"names__0_sqlp"': src_params['names'][0],
+			'"names__1_sqlp"': src_params['names'][1],
+		}
 
 		# Format SQL with params.
 		sql, params = query.format(src_sql, src_params)
@@ -277,8 +640,8 @@ class Test(unittest.TestCase):
 
 	def test_2_expand_tuples_default(self):
 		"""
-		Test the default behavior for expanding tuples. A named out-style
-		should be disabled by default.
+		Test the default behavior for expanding tuples. A named out-style should be
+		disabled by default.
 		"""
 		# Create instance.
 		query = sqlparams.SQLParams('named', 'named')
@@ -391,7 +754,11 @@ class Test(unittest.TestCase):
 			FROM users
 			WHERE race = :race AND name IN (:names__0_sqlp,:names__1_sqlp);
 		"""
-		dest_params = [{'race': __row['race'], 'names__0_sqlp': __row['names'][0], 'names__1_sqlp': __row['names'][1]} for __row in src_params]
+		dest_params = [{
+			'race': __row['race'],
+			'names__0_sqlp': __row['names'][0],
+			'names__1_sqlp': __row['names'][1],
+		} for __row in src_params]
 
 		# Format SQL with params.
 		sql, many_params = query.formatmany(src_sql, src_params)
